==> mono_4.6.2.7+dfsg.orig.tar.gz: mono-4.6.2+dfsg/mcs/class/Facades/System.Text.Encoding.CodePages/CodePagesEncodingProvider.cs <==
// 
// Copyright (c) 2016 Xamarin Inc. (http://www.xamarin.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
// 

namespace System.Text
{
	public sealed partial class CodePagesEncodingProvider : EncodingProvider
	{
		static CodePagesEncodingProvider instance = new CodePagesEncodingProvider ();

		private CodePagesEncodingProvider ()
		{
		}
		
		public static System.Text.EncodingProvider Instance { 
			get {
				return instance;
			}
		}

		public override Encoding GetEncoding (string name)
		{
			// MSDN: "if name is not the name of an encoding that you support, the method should return null."
			// We do this here since all our encodings are already supported by the main Encoding class
			return null;
		}

		public override Encoding GetEncoding (int codepage)
		{
			// MSDN: "if codepage is not the code page identifier of an encoding that you support, the method should return null."
			// We do this here since all our encodings are already supported by the main Encoding class
			return null;
		}
	}
}

==> mono_5.18.0.240+dfsg.orig.tar.gz: mono-5.18.0.240+dfsg/mcs/class/Facades/System.Text.Encoding.CodePages/CodePagesEncodingProvider.cs <==
// 
// Copyright (c) 2016 Xamarin Inc. (http://www.xamarin.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
// 

namespace System.Text
{
	public sealed class CodePagesEncodingProvider : EncodingProvider
	{
		static readonly CodePagesEncodingProvider instance = new CodePagesEncodingProvider ();

		private CodePagesEncodingProvider ()
		{
		}
		
		public static EncodingProvider Instance {
			get {
				return instance;
			}
		}

		public override Encoding GetEncoding (string name)
		{
			// MSDN: "if name is not the name of an encoding that you support, the method should return null."
			// We do this here since all our encodings are already supported by the main Encoding class
			return null;
		}

		public override Encoding GetEncoding (int codepage)
		{
			// MSDN: "if codepage is not the code page identifier of an encoding that you support, the method should return null."
			// We do this here since all our encodings are already supported by the main Encoding class
			return null;
		}
	}
}
